//---------------------------------------------------------------------------


#pragma hdrstop

#include <IniFiles.hpp>
#include "Settings.h"

//---------------------------------------------------------------------------

#pragma package(smart_init)

bool Settings::Read(AnsiString asFileName)
{
	TIniFile *ini = NULL;
	try
	{
		ini = new TIniFile(asFileName);
		// main window startup position
		int maxX = GetSystemMetrics(SM_CXSCREEN);
		int maxY = GetSystemMetrics(SM_CYSCREEN);
		iWidth = ini->ReadInteger("GUI", "AppWidth", 350);
		iHeight = ini->ReadInteger("GUI", "AppHeight", 300);
		if (iWidth < 250 || iWidth > maxX + 20)
		{
			iWidth = 250;
		}
		if (iHeight < 200 || iHeight > maxY + 20)
		{
			iHeight = 200;
		}
		iPosX = ini->ReadInteger("GUI", "AppPositionX", 30);
		iPosY = ini->ReadInteger("GUI", "AppPositionY", 30);
		if (iPosX < 0)
			iPosX = 0;
		if (iPosY < 0)
			iPosY = 0;
		if (iPosX + iWidth > maxX)
			iPosX = maxX - iWidth;
		if (iPosY + iHeight > maxY)
			iPosY = maxY - iHeight;
		bWindowMaximized = ini->ReadBool("GUI", "Maximized", false); 
		bAlwaysOnTop = ini->ReadBool("GUI", "AlwaysOnTop", false);

		bDetectIpAtConnect = ini->ReadBool("Application", "DetectIpAtConnect", true);
		bKeepAlive = ini->ReadBool("Application", "KeepAlive", true);
		bSendOnEnter = ini->ReadBool("Application", "SendOnEnter", true);
		bAutoScroll = ini->ReadBool("Application", "AutoScroll", true);
		iMaxUiLogLines = ini->ReadInteger("Application", "MaxUiLogLines", 1000);
		iAfterSend = ini->ReadInteger("Application", "AfterSend", AFTERSEND_NONE);
		bAutoComplete = ini->ReadBool("Application", "AutoComplete", true);
		bAutoCompleteCaseSensitive = ini->ReadBool("Application", "AutoCompleteCaseSensitive", true);
		iSendSuffix = ini->ReadInteger("Application", "SendSuffix", SENDSUFFIX_CRLF);
		bClearWindowAtReconnect = ini->ReadBool("Application", "ClearWindowAtReconnect", false);

		delete ini;
	}
	catch (...)
	{
		if (ini)
		{
			delete ini;
		}
		return false;
	}
	return true;
}

bool Settings::Write(AnsiString asFileName)
{
	TIniFile *ini = NULL;
	try
	{
		ini = new TIniFile(asFileName);
		ini->WriteInteger("GUI", "AppWidth", iWidth);
		ini->WriteInteger("GUI", "AppHeight", iHeight);
		ini->WriteInteger("GUI", "AppPositionX", iPosX);
		ini->WriteInteger("GUI", "AppPositionY", iPosY);
		ini->WriteBool("GUI", "Maximized", bWindowMaximized);		
		ini->WriteBool("GUI", "AlwaysOnTop", bAlwaysOnTop);
		ini->WriteBool("Application", "DetectIpAtConnect", bDetectIpAtConnect);
		ini->WriteBool("Application", "KeepAlive", bKeepAlive);		
		ini->WriteBool("Application", "SendOnEnter", bSendOnEnter);
		ini->WriteBool("Application", "AutoScroll", bAutoScroll);
		ini->WriteInteger("Application", "MaxUiLogLines", iMaxUiLogLines);
		ini->WriteInteger("Application", "AfterSend", iAfterSend);
		ini->WriteBool("Application", "AutoComplete", bAutoComplete);
		ini->WriteBool("Application", "AutoCompleteCaseSensitive", bAutoCompleteCaseSensitive);
		ini->WriteInteger("Application", "SendSuffix", iSendSuffix);
		ini->WriteBool("Application", "ClearWindowAtReconnect", bClearWindowAtReconnect);

		delete ini;
	}
	catch (...)
	{
		if (ini)
		{
			delete ini;
		}
		return false;
	}
	return true;

}
